@@ -39,7 +39,6 @@ from tqdm import tqdm
 from skimage.util import random_noise
 from scipy.ndimage import distance_transform_edt
 from skimage.morphology import skeletonize
-globalthreshold = 0.01
 
 
 def BinaryLabel(BinaryImageOriginal, max_size = 15000):
@@ -132,7 +131,7 @@ def expand_labels(label_image, distance=1):
     labels_out[dilate_mask] = nearest_labels
     return labels_out
 
-def SimplePrediction(x, UnetModel, StarModel, n_tiles = (2,2), UseProbability = True, min_size = 20, axis = 'ZYX'):
+def SimplePrediction(x, UnetModel, StarModel, n_tiles = (2,2), UseProbability = True, min_size = 20, axis = 'ZYX', globalthreshold = 1.0E-5):
     
                
     
@@ -140,7 +139,7 @@ def SimplePrediction(x, UnetModel, StarModel, n_tiles = (2,2), UseProbability =
                                            
                       Mask = UNETPrediction3D(x, UnetModel, n_tiles, axis)
                       
-                      SmartSeeds, _, StarImage = STARPrediction3D(x, StarModel, n_tiles, MaskImage = Mask, smartcorrection = None, UseProbability = UseProbability)
+                      SmartSeeds, _, StarImage = STARPrediction3D(x, StarModel, n_tiles, MaskImage = Mask, smartcorrection = None, UseProbability = UseProbability, globalthreshold = globalthreshold)
                       
                       SmartSeeds = SmartSeeds.astype('uint16') 
                      
@@ -475,7 +474,7 @@ def SmartSeedPredictionSliced(SaveDir, fname, UnetModel, StarModel, NoiseModel =
     
     
 def SmartSeedPrediction3D( SaveDir, fname,  UnetModel, StarModel, NoiseModel = None, min_size_mask = 100, min_size = 10, 
-n_tiles = (1,2,2), doMask = True, smartcorrection = None, threshold = 20, projection = False, UseProbability = True, filtersize = 0):
+n_tiles = (1,2,2), doMask = True, smartcorrection = None, threshold = 20, projection = False, UseProbability = True, filtersize = 0, globalthreshold = 1.0E-5):
     
     
     
@@ -511,9 +510,9 @@ n_tiles = (1,2,2), doMask = True, smartcorrection = None, threshold = 20, projec
         Mask[i,:] = remove_small_objects(Mask[i,:].astype('uint16'), min_size = min_size)
     
     SizedMask[:, :Mask.shape[1], :Mask.shape[2]] = Mask
-    
+    imwrite((UNETResults + Name+ '.tif' ) , SizedMask.astype('uint16')) 
     print('Stardist segmentation on Image')  
-    SmartSeeds, _, StarImage = STARPrediction3D(gaussian_filter(image,filtersize), StarModel,  n_tiles, MaskImage = Mask, UseProbability = UseProbability, smartcorrection = smartcorrection)
+    SmartSeeds, _, StarImage = STARPrediction3D(gaussian_filter(image,filtersize), StarModel,  n_tiles, MaskImage = Mask, UseProbability = UseProbability, smartcorrection = smartcorrection, globalthreshold = globalthreshold)
     SmartSeeds= remove_small_objects(SmartSeeds.astype('uint16'), min_size = min_size)
     SmartSeeds = fill_label_holes(SmartSeeds.astype('uint16'))
     SmartSeeds = RemoveLabels(SmartSeeds) 
@@ -521,7 +520,7 @@ n_tiles = (1,2,2), doMask = True, smartcorrection = None, threshold = 20, projec
             
     imwrite((StarDistResults + Name+ '.tif' ) , StarImage.astype('uint16'))
     imwrite((SmartSeedsResults + Name+ '.tif' ) , SizedSmartSeeds.astype('uint16'))
-    imwrite((UNETResults + Name+ '.tif' ) , SizedMask.astype('uint16')) 
+    
     
         
     return SizedSmartSeeds, SizedMask    
@@ -530,7 +529,7 @@ n_tiles = (1,2,2), doMask = True, smartcorrection = None, threshold = 20, projec
 
 def Integer_to_border(Label):
 
-        BoundaryLabel =  find_boundaries(SmallLabel, mode='outer')
+        BoundaryLabel =  find_boundaries(Label, mode='outer')
            
         Binary = BoundaryLabel > 0
         
@@ -690,7 +689,7 @@ def RemoveLabels(LabelImage, minZ = 2):
                     LabelImage[LabelImage == regionlabel] = 0
     return LabelImage                
 
-def STARPrediction3D(image, model, n_tiles, MaskImage = None, smartcorrection = None, UseProbability = True):
+def STARPrediction3D(image, model, n_tiles, MaskImage = None, smartcorrection = None, UseProbability = True, globalthreshold = 1.0E-5):
     
     copymodel = model
     image = normalize(image, 1, 99.8, axis = (0,1,2))
@@ -698,11 +697,13 @@ def STARPrediction3D(image, model, n_tiles, MaskImage = None, smartcorrection =
     image = zero_pad_time(image, 64, 64)
     grid = copymodel.config.grid
 
+    print('Predicting Instances')
     MidImage, details = model.predict_instances(image, n_tiles = n_tiles)
+    print('Predicting Proabbilities')
     SmallProbability, SmallDistance = model.predict(image, n_tiles = n_tiles)
 
 
-
+    print('Predictions Done')
     StarImage = MidImage[:image.shape[0],:shape[0],:shape[1]]
     if UseProbability == False:
         
@@ -711,6 +712,7 @@ def STARPrediction3D(image, model, n_tiles, MaskImage = None, smartcorrection =
     
     Probability = np.zeros([SmallProbability.shape[0] * grid[0],SmallProbability.shape[1] * grid[1], SmallProbability.shape[2] * grid[2] ])
     
+    print('Reshaping')
     #We only allow for the grid parameter to be 1 along the Z axis
     for i in range(0, SmallProbability.shape[0]):
         Probability[i,:] = cv2.resize(SmallProbability[i,:], dsize=(SmallProbability.shape[2] * grid[2] , SmallProbability.shape[1] * grid[1] ))
@@ -719,17 +721,18 @@ def STARPrediction3D(image, model, n_tiles, MaskImage = None, smartcorrection =
     
     if UseProbability:
         
-        
+        print('Using Probability maps')
         Probability[Probability < globalthreshold ] = 0 
              
         MaxProjectDistance = Probability[:image.shape[0],:shape[0],:shape[1]]
 
     else:
         
+        print('Using Distance maps')
         MaxProjectDistance = Distance[:image.shape[0],:shape[0],:shape[1]]
 
     
-          
+    print('Doing Watershedding')      
     Watershed, Markers = WatershedwithMask3D(MaxProjectDistance.astype('uint16'), StarImage.astype('uint16'), MaskImage.astype('uint16'), grid )
     Watershed = fill_label_holes(Watershed.astype('uint16'))
   
